@@ -4,7 +4,7 @@ from django.db import models
 from django.utils.translation import ugettext_lazy as _
 
 from knowledge.managers import QuestionManager, ResponseManager
-from knowledge.signals import response_post_save
+from knowledge.signals import knowledge_post_save
 
 STATUSES = (
     ('public', _('Public')),
@@ -23,11 +23,14 @@ class Category(models.Model):
     lastchanged = models.DateTimeField(auto_now=True)
 
     title = models.CharField(max_length=255)
-    slug = models.SlugField()
+    slug = models.SlugField(unique=True)
 
     def __unicode__(self):
         return self.title
 
+    class Meta:
+        ordering = ['title']
+
 
 class KnowledgeBase(models.Model):
     """
@@ -104,15 +107,19 @@ class KnowledgeBase(models.Model):
 
     def public(self, save=True):
         self.switch('public', save)
+    public.alters_data = True
 
     def private(self, save=True):
         self.switch('private', save)
+    private.alters_data = True
 
     def inherit(self, save=True):
         self.switch('inherit', save)
+    inherit.alters_data = True
 
     def internal(self, save=True):
         self.switch('internal', save)
+    internal.alters_data = True
 
     class Meta:
         abstract = True
@@ -126,13 +133,8 @@ class KnowledgeBase(models.Model):
         if settings.AUTO_PUBLICIZE and not self.id:
             self.public(save=False)
 
-        created = not bool(self.id)
-
         super(KnowledgeBase, self).save(*args, **kwargs)
 
-        if self.is_response:
-            response_post_save(self, created)
-
 
 class Question(KnowledgeBase):
     is_question = True
@@ -151,7 +153,7 @@ class Question(KnowledgeBase):
 
     locked = models.BooleanField(default=False)
 
-    categories = models.ManyToManyField('knowledge.Category')
+    categories = models.ManyToManyField('knowledge.Category', blank=True)
 
     objects = QuestionManager()
 
@@ -161,10 +163,11 @@ class Question(KnowledgeBase):
     def internal(self):
         pass
 
-    def flip_lock(self, save=True):
+    def lock(self, save=True):
         self.locked = not self.locked
         if save:
             self.save()
+    lock.alters_data = True
 
     ###################
     #### RESPONSES ####
@@ -191,6 +194,7 @@ class Question(KnowledgeBase):
 
     def clear_accepted(self):
         self.get_responses().update(accepted=False)
+    clear_accepted.alters_data = True
 
     def accept(self, response=None):
         """
@@ -205,12 +209,13 @@ class Question(KnowledgeBase):
             return True
         else:
             return False
+    accept.alters_data = True
 
     def states(self):
         """
         Handy for checking for mod bar button state.
         """
-        return [self.status, 'flip_lock' if self.locked else None]
+        return [self.status, 'lock' if self.locked else None]
 
     @property
     def url(self):
@@ -257,9 +262,15 @@ class Response(KnowledgeBase):
 
     def accept(self):
         self.question.accept(self)
+    accept.alters_data = True
 
     def __unicode__(self):
         return self.body[0:100] + u'...'
 
     class Meta:
         ordering = ['added']
+
+
+# cannot attach on abstract = True... derp
+models.signals.post_save.connect(knowledge_post_save, sender=Question)
+models.signals.post_save.connect(knowledge_post_save, sender=Response)
